@@ -26,7 +26,7 @@ from albatross.common import *
 # old cPickle used string exceptions, and therefore couldn't subclass a common
 # exception. New cPickle has a common cPickle.PickleError, but will also raise
 # some other random exceptions - bah - these are the ones I've seen:
-pickle_errors = (cPickle.PicklingError, 
+pickle_errors = (cPickle.PicklingError,
                  cPickle.UnpicklingError,
                  TypeError,
                  EOFError)
@@ -70,7 +70,7 @@ class ResourceMixin:
             else:
                 if existing_loc != macro_loc:
                     raise ApplicationError('macro %r already defined in %s:%s' %
-                                           (name, existing_loc[0], 
+                                           (name, existing_loc[0],
                                             existing_loc[1]))
         self.__macros[name] = macro
 
@@ -88,7 +88,7 @@ class ResourceMixin:
             else:
                 if existing_loc != lookup_loc:
                     raise ApplicationError('lookup %r already defined in %s:%s'%
-                                           (name, existing_loc[0], 
+                                           (name, existing_loc[0],
                                             existing_loc[1]))
         self.__lookups[name] = lookup
 
@@ -394,26 +394,26 @@ class NamespaceMixin:
             raise SecurityError('cannot merge %s into namespace' % name)
         # handle iterator back door; op,iter[,value]
         elems = name.split(',')
-        if len(elems) >= 2:
-            op = elems[0]
-            iter = self.get_value(elems[1])
-            if iter:
-                if len(elems) > 2:
-                    # tree operation
-                    iter.set_backdoor(op, elems[2], value)
-                else:
-                    iter.set_backdoor(op, value)
-            return
+        method = None
+        if len(elems) > 1:
+            method = 'set_backdoor'
+            name = elems[1]
+            if len(elems) > 2:
+                args = (elems[0], elems[2], value)
+            else:
+                args = (elems[0], value)
         # handle a[12].b or a.b[12]
         try:
             ID = 0; DOT_OR_OPEN = 1; INDEX = 2; CLOSE = 3
             parent = self.locals
             index = None
-            elem = None
             state = ID
             elems = filter(None, _re_tokens.split(name))
+            elem = elems[-1]            # For error reporting
             for elem in elems[:-1]:
                 if state == ID:
+                    if elem in '.[':
+                        raise SyntaxError
                     parent = getattr(parent, elem)
                     state = DOT_OR_OPEN
                 elif state == DOT_OR_OPEN:
@@ -424,16 +424,26 @@ class NamespaceMixin:
                     else:
                         raise SyntaxError
                 elif state == INDEX:
-                    index = int(elem)
+                    index = elem
                     state = CLOSE
                 elif state == CLOSE:
-                    parent = parent[index]
+                    if index is None or elem != ']':
+                        raise SyntaxError
+                    parent = parent[int(index)]
                     index = None
                     state = DOT_OR_OPEN
             if state == ID:
-                setattr(parent, elems[-1], value)
+                if method:
+                    meth = getattr(getattr(parent, elems[-1]), method)
+                    meth(*args)
+                else:
+                    setattr(parent, elems[-1], value)
             elif state == CLOSE and elems[-1] == ']' and index is not None:
-                parent[index] = value
+                if method:
+                    meth = getattr(parent[int(index)], method)
+                    meth(*args)
+                else:
+                    parent[int(index)] = value
             else:
                 raise SyntaxError
         except:
@@ -450,7 +460,7 @@ class NamespaceMixin:
                         ptr = 'near ^'
                         pad = msg.find('"') - len(ptr) + 2
                         for e in elems[:-1]:
-                            if e == elem:
+                            if e is elem:
                                 break
                             pad = pad + len(e)
                         exc_value = '%s\n%s%s' % (exc_value, ' ' * pad, ptr)
@@ -678,10 +688,7 @@ class HiddenFieldSessionMixin(SessionBase):
 # ------------------------------------------------------------------
 
 def _caller_globals(name):
-    try:
-        raise ZeroDivisionError
-    except ZeroDivisionError:
-        frame = sys.exc_traceback.tb_frame
+    frame = sys._getframe(1)
     while frame.f_code.co_name != name:
         frame = frame.f_back
     while frame.f_code.co_name == name:
