@@ -9,7 +9,7 @@
 # Unfortunately, we need to have intimate knowledge of the encoding scheme used
 # by the NameRecorderMixin - changes there will need to be reflected here.
 #
-# $Id: recorder.py,v 1.6 2003/09/21 04:40:31 djc Exp $
+# $Id: recorder.py,v 1.7 2005/05/19 14:04:28 andrewm Exp $
 
 import re, os, sys
 
@@ -27,9 +27,10 @@ hidden field with an appropriate value.
 """
 albform_re = re.compile(r'<input type="hidden" name="__albform__" value="([^"]*)" />', re.I|re.M|re.S)
 
-class RecorderTestApp(albatross.Application):
-    def __init__(self):
-        albatross.Application.__init__(self, 'here')
+class RecorderTestApp(albatross.TemplateLoaderMixin, albatross.Application):
+    def __init__(self, base_url):
+        albatross.TemplateLoaderMixin.__init__(self, base_url)
+        albatross.Application.__init__(self, base_url)
 
     def pickle_sign(self, text):
         # albatross.Application discards text, we need a pass-thru
@@ -38,12 +39,11 @@ class RecorderTestApp(albatross.Application):
     def pickle_unsign(self, text):
         return text
 
-class RecorderTestContext(albatross.TemplateLoaderMixin,
-                  albatross.AppContext, albatross.NameRecorderMixin,
-                  albatross.StubSessionMixin):
-    def __init__(self, template_path):
-        albatross.TemplateLoaderMixin.__init__(self, template_path)
-        albatross.AppContext.__init__(self, RecorderTestApp())
+class RecorderTestContext(albatross.AppContext, albatross.NameRecorderMixin,
+                          albatross.StubSessionMixin):
+    def __init__(self, template_dir):
+        app = RecorderTestApp(template_dir)
+        albatross.AppContext.__init__(self, app)
         albatross.NameRecorderMixin.__init__(self)
 
     def current_url(self):
