@@ -6,7 +6,7 @@
 # 
 # Form functionality tests.
 #
-# $Id: form.py,v 1.18 2003/09/21 04:40:31 djc Exp $
+# $Id: form.py,v 1.19 2005/04/19 09:53:58 andrewm Exp $
 
 import unittest
 import albatross
@@ -135,6 +135,10 @@ class SelectCase(albatross_test.AlbatrossTestCase):
         self.ctx.locals.sel = 'spam'
         self.html_test("select-value.html", '<select name="sel"><option value="spam" selected>canned meat product</option><option>eggs</option></select>')
 
+    def check_select_name_expr(self):
+        self.ctx.locals.val = 'spam'
+        self.html_test("select-name-expr.html", '<select name="sel"><option selected>spam</option><option>eggs</option></select>')
+
     def check_select_optionexpr(self):
         self.ctx.locals.sel = '3'
         self.ctx.locals.opt = range(5)
@@ -180,6 +184,7 @@ class SelectSuite(unittest.TestSuite):
         "check_select",
         "check_select_evaluate",
         "check_select_value",
+        "check_select_name_expr",
         "check_select_optionexpr",
         "check_select_optionexpr_pairs",
         "check_select_optionexpr_escaping",
