@@ -6,7 +6,7 @@
 # 
 # Test tree constructs.
 #
-# $Id: tree.py,v 1.7 2003/09/21 04:40:31 djc Exp $
+# $Id: tree.py,v 1.8 2005/04/19 09:53:58 andrewm Exp $
 
 import unittest
 import albatross
@@ -38,8 +38,8 @@ tree_input_folded="""\
     <td colspan="999" nowrap>a</td>
    </tr>
   </table>
-<input type="hidden" name="__albform__" value="eJwDAAAAAAE=
-" />
+<div><input type="hidden" name="__albform__" value="eJwDAAAAAAE=
+" /></div>
 </form>"""
 
 tree_input_unfolded="""\
@@ -86,8 +86,8 @@ tree_input_unfolded="""\
     <td colspan="999" nowrap>k</td>
    </tr>
   </table>
-<input type="hidden" name="__albform__" value="eJwDAAAAAAE=
-" />
+<div><input type="hidden" name="__albform__" value="eJwDAAAAAAE=
+" /></div>
 </form>"""
 
 tree_input_unfolded_selected="""\
@@ -134,8 +134,8 @@ tree_input_unfolded_selected="""\
     <td colspan="999" nowrap>k</td>
    </tr>
   </table>
-<input type="hidden" name="__albform__" value="eJwDAAAAAAE=
-" />
+<div><input type="hidden" name="__albform__" value="eJwDAAAAAAE=
+" /></div>
 </form>"""
 
 class SimpleNode:
